@@ -4,52 +4,92 @@ use 5.010;
 use strict;
 use warnings;
 
-use base 'Csistck::Test::FileBase';
-use Csistck::Oper qw/debug/;
-use Csistck::Util qw/hash_file hash_string/;
-
+use base 'Exporter';
 our @EXPORT_OK = qw/file/;
 
+use Csistck::Oper qw/debug/;
+use Csistck::Util qw/backup_file hash_file/;
+use Csistck::Test;
+
 use Digest::MD5;
 use File::Basename;
 use File::Copy;
 use FindBin;
-use File::stat;
-use Template;
-use Sys::Hostname::Long qw//;
-use Text::Diff ();
 
-sub file { Csistck::Test::File->new(@_); };
+sub file {
+    my $src = shift;
+    my $dest = shift;
+    my $args = shift;
 
-sub desc { sprintf("File check on %s", shift->dest); }
-
-sub file_check {
-    my $self = shift;
-    my ($dest, $src) = ($self->dest, $self->src);
-    file_compare($src, $dest);
-}
-
-sub file_repair {
-    my $self = shift;
-    my ($dest, $src) = ($self->dest, $self->src);
-    debug("Copying file: <src=$src> <dest=$dest>");
-    copy($src, $dest);
-}
+    # Get absolute paths for glob, glob files
+    my $src_abs = join '/', $FindBin::Bin, $src;
+    my @files = glob($src_abs);
     
+    # Return array of tests
+    return map { file_build_test($_, $dest); } @files;
+}
+
+# Helper function to avoid same scope in map and to build test
+sub file_build_test {
+    my ($src, $dest) = @_;
+    
+    # Test destination for file
+    my $src_base = basename($src);
+    my $dest_abs = join "/", $dest, $src_base;
+
+    return Csistck::Test->new(
+        check => sub { file_check($src, $dest_abs); },
+        repair => sub { file_install($src, $dest_abs); },
+        diff => sub { file_diff($src, $dest_abs); },
+        desc => "File check on $src"
+    );
+}
+
+# Check file and file in destination are the same via md5
+sub file_check {
+    my $src = shift;
+    my $dest = shift;
+
+    die("Files do not match: src=<$src> dest=<$dest>")
+      unless(file_compare($src, $dest));
+}
+
+# Copy file to destination
+sub file_install {
+    my ($src, $dest) = @_;
+    
+    backup_file($dest)
+      if(-f -e -r $dest);
+
+    debug("Copying file: <src=$src> <dest=$dest>");
+
+    copy($src, $dest) or die("Failed to copy file: $!: src=<$src> dest=<$dest>");
+}
+
+# Diff for files
 sub file_diff {
-    my $self = shift;
-    my ($dest, $src) = ($self->dest, $self->src);
-    say(Text::Diff::diff($dest, $src));
+    my ($src, $dest) = @_;
+
+    if(-f -e -r $dest) {
+        say(Text::Diff::diff($dest, $src));
+    }
+    else {
+        die("Destination file does not exist: dest=<$dest>");
+    };
 }
 
 # Compare hashes between two files
 sub file_compare {
     my @files = @_;
+
+    # Require two files
     return 0 unless (scalar @files == 2);
-    
+
     # Get hashes and return compare
     my ($hasha, $hashb) = map hash_file($_), @files;
+
     debug(sprintf "File compare result: <hash=%s> <hash=%s>", $hasha, $hashb);
+    
     return ($hasha eq $hashb);
 }
 
@@ -58,28 +98,16 @@ __END__
 
 =head1 NAME
 
-Csistck::Test::Template - Csistck template check
+Csistck::Test::File - Csistck file check
 
 =head1 DESCRIPTION
 
 =head1 METHODS
 
-=head2 template($template, $target, [%args])
+=head2 file($glob, $target)
 
-Process template toolkit file and output to target path. Target
-path should be a file in an existing path. 
-
-    role 'test' => template('sys/motd.tt', '/etc/motd', { production => 1 });
-
-Some arguments are automatically passed to the template processor:
-
-=over
-
-=item hostname
-
-The full hostname of the current system
-
-=back
+Select files using file glob pattern and copy files into target path. Target
+path should be a directory, not a file.
 
 =head1 AUTHOR
 
@@ -109,4 +137,3 @@ THE SOFTWARE.
 
 =cut
 
-
